EasyChromecastPluginWeb class

Constructors

EasyChromecastPluginWeb()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

disconnectDevice() Future<void>
initializeCast() Future<void>
isConnected() Future<bool>
pauseMedia() Future<void>
playMedia(String url, String title) Future<void>
registerWith(Registrar registrar) → void
resumeMedia() Future<void>
seekMedia(int positionInSeconds) Future<void>
setVolume(double volume) Future<void>
showCastDialog() Future<void>
stopMedia() Future<void>